@@ -4,9 +4,14 @@ from jcopvision.exception import IncorrectExtensionError
 
 class BaseWriter:
     def __init__(self, output_path, width, height, fps, fourcc):
-        self._writer = cv2.VideoWriter(output_path, fourcc, fps, (int(width), int(height)))
+        self.width = int(width)
+        self.height = int(height)
+        self._writer = cv2.VideoWriter(output_path, fourcc, fps, (self.width, self.height))
 
     def write(self, frame):
+        h, w, c = frame.shape
+        if (w != self.width) | (h != self.height):
+            frame = cv2.resize(frame, (self.width, self.height))
         self._writer.write(frame)
 
     def close(self):
